:mod:`{{fullname}}` 
======================

.. currentmodule:: {{fullname}}


.. automodule:: {{fullname}}
   :members:
   
   .. autosummary:: 
   {% for element in functions %}
      {{element}}
   {% endfor %}
   
   .. rubric:: Functions

   
